import { select, geoPath, geoMercator, zoom, event, scaleOrdinal, schemeCategory10, csv, json, geoCentroid, scaleSqrt, max, format } from 'd3';
//import { feature } from 'topojson';
import { loadAndProcessData } from './UTils';
import {sizeLengend} from './sizeLengend';

//const svg = select('svg').attr("width", 500).attr("height", 300);
const svg = select('svg');
const g = svg.append('g').attr('transform', 'translate(-300,100)');
const width = +svg.attr('width');
const height = +svg.attr('height');
const projection = geoMercator();
const pathGenerator = geoPath().projection(projection);
const radiusUnknownValue = d => d.properties.Relative;
const colorScale = scaleOrdinal(schemeCategory10);
const str_title = 'xxxx plot';
const affectTypeText = 'Relative';

loadAndProcessData().then(china_map => {
	const sizeScale = scaleSqrt()
    .domain([0, 500])
  	.range([0, 20]);
  
  svg.append('g')
		.attr('transform', `translate(20, 100)`)
  	.append('text')
  		.attr("font-size", "80px")
  		.text("C")
  		.attr('x', 10)
  		.attr('y', -30);
  
  svg.append('g')
		.attr('transform', `translate(850, 300)`)
		.call(sizeLengend, {
    	sizeScale,
  		spacing: 40,
  		textOffset: 20,
  		numTicks: 5,
  		circleFill: 'rgba(165,42,42,0.5)',
    	tickFormat: format(',')})
  	.append('text')
  		.text(affectTypeText)
  		.attr("font-size", "40px")
  		.attr('x', -60)
  		.attr('y', -30);
  
  projection
      .scale(600)
      .center([80, 30.0]);
  
  g.selectAll('path')
  	.data(china_map.features)
    .enter().append('path')
  		.attr('d', pathGenerator)
  		.attr('class', 'province')
  		.attr('fill', d => colorScale(d.properties.ID_1))
  	.append('title')
  		.text(d => d.properties.Province);
  
  g.selectAll('circle').data(china_map.features)
  	.enter()
    	.append('circle')
  			.attr('class', 'unknown-circle')
  			.attr('cx', d => projection(geoCentroid(d))[0])
  			.attr('cy', d => projection(geoCentroid(d))[1])
  			.attr('r', d => sizeScale(radiusUnknownValue(d)));
  
});